#
# spec file for package quazip
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define  so_ver 1

Name:           quazip
Version:        0.7.1
Release:        30.1
Summary:        C++ wrapper for ZIP/UNZIP
License:        GPL-2.0+ or LGPL-2.1+
Group:          Development/Libraries/C and C++

Url:            http://quazip.sourceforge.net/
Source0:        http://sourceforge.net/projects/quazip/files/quazip/%{version}/quazip-%{version}.tar.gz
Patch0:         quazip-0.7.1-r260.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(QtCore)

%description
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt4 toolkit.
Useful to access ZIP archives from the Qt programs.

%package -n libquazip%{so_ver}
Summary:        C++ wrapper for ZIP/UNZIP
Group:          Development/Libraries/C and C++

%description -n libquazip%{so_ver}
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt4 toolkit.
Useful to access ZIP archives from the Qt programs.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libquazip%{so_ver} = %{version}-%{release}
Requires:       pkgconfig(QtCore)

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        C++ wrapper for ZIP/UNZIP
Group:          Development/Libraries/C and C++

%description doc
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt4 toolkit.
Useful to access ZIP archives from the Qt programs.


%prep
%setup -q
%patch0 -p1

%build
echo 'HTML_TIMESTAMP=NO' >> Doxyfile
pushd quazip
qmake PREFIX=%{_prefix} QMAKE_CFLAGS="%optflags" QMAKE_CXXFLAGS="%optflags -fvisibility-inlines-hidden"
%__make %{?_smp_mflags}
popd
doxygen -u
doxygen

%install
pushd quazip
%__make install INSTALL_ROOT=%{buildroot}
if [ "%{_lib}" != "lib" ]; then
  %__mv %{buildroot}%{_prefix}/lib %{buildroot}%{_libdir}
fi
popd
pushd doc/html
%fdupes -s .
popd

%post -n libquazip%{so_ver} -p /sbin/ldconfig

%postun -n libquazip%{so_ver} -p /sbin/ldconfig

%files -n libquazip%{so_ver}
%defattr(-,root,root,-)
%doc COPYING* NEWS.txt README.txt
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so

%files doc
%defattr(-,root,root,-)
%doc doc/html

%changelog
* Wed Nov  4 2015 hpj@urpla.net
- streamline quazip and libquaszip-qt5 specs
- rename libquaszip-qt5.* to quaszip-qt5.*
- apply quazip-0.7.1-r260.diff generated from svn
  svn diff -r r250:r260
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 0.7.1
  * Fixed licensing issues (bug #45).
  * Added the convenience method QuaZipFileInfo::isEncrypted().
- Changes from version 0.7
  * It is now possible to write ZIP files to sequential devices like
    sockets (only in mdCreate mode, so no self-extract, sorry).
  * A few zip64 fixes.
  * Several bug fixes and portability improvements.
- Changes from version 0.6.2
  * QuaZipNewInfo / QuaZipFileInfo64 now provide API to access/set
    NTFS time stamps - useful even on non-NTFS systems if you
    need more precise dates and times than default ones.
  * QuaZipNewInfo may now be initialized from QuaZipFileInfo64.
  * No more crashes when using QSaveFile as QIODevice for ZIP.
  * The new QuaZip::setAutoClose() method allows to leave the
    QIODevice open when you close the QuaZip instance.
  * qztest now depends on quazip, no longer breaking the build.
- Changes from version 0.6.1
  * Improved zip64 support.
  * A LOT more tests thanks to g++ --coverage / lcov.
  * JlCompress extraction methods now create files with default
    permissions if they are zero in the original archive.
  * Some QuaZipDir fixes (thanks to the new tests).
- Changes from version 0.6
  * Minizip updated to 1.1 (with all the necessary modifications
    re-done), and that means that...
  * the long-awaited zip64 support is now available!
  * A few rather minor fixes.
- Changes from version 0.5.2
  * Some minor bug fixes.
  * API to access file permissions subfield of the external
    attributes.
  * MS VS 2012 Express support.
  * API to set the default codec used to encode/decode file names
    (mainly for use by various wrappers such as JlCompress, when
    you don't have direct access to the underlying QuaZip instance).
* Sat Oct 11 2014 crrodriguez@opensuse.org
- quazip-devel should require pkgconfig(qtcore)
- Build shared library with -fvisibility-inlines-hidden
- Ensure doxygen does not create html files with timestamps.
* Sat Sep  7 2013 stefan@fam-elser.de
- Update to 0.5.1 version:
  * Lots of QuaZipDir fixes, thanks to all bug reporters.
  * Full Qt Creator support.
  * MS VS 2010 Express support.
  * Qt5 support (didn't need any source code changes anyway).
  * Lots of minor bug fixes.
* Sat Dec 15 2012 p.drouand@gmail.com
- Update to 0.5 version:
  * Added run_moc.bat files for building under Windows in case Qt
    integration is not available (e. g. VS 2008 Express).
  * Added the QuaZipDir class to simplify ZIP navigation in terms
    of directories.
  * Added the QuaGzipFile class for working with GZIP archives. It
    was added as a bonus since it has nothing to do with the main
    purpose of the library. It probably won't get any major
    improvements, although minor bug fixes are possible.
  * Added the QuaZIODevice class for working with zlib
    compression. It has nothing to do with the ZIP format, and
    therefore the same notice as for the QuaGzipFile applies.
  * The global comment is no longer erased when adding files to
    an archive.
  * Many bug fixes.
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Mon Sep 12 2011 adam@mizerski.pl
- update to 0.4.3
  See NEWS for details
* Wed Sep  7 2011 adam@mizerski.pl
- update to 0.4.2
  See NEWS for details
* Fri May 27 2011 cfarrell@novell.com
- license update: GPL-2.0+ or LGPL-2.1+
  Update license syntax. Also GPLv2 was not correct. It is an ^or later^
  clause
* Wed Feb 23 2011 adam@mizerski.pl
- new package
